@@ -35,6 +35,7 @@
 #define META_WINDOW_PRIVATE_H
 
 #include <config.h>
+#include "compositor.h"
 #include "window.h"
 #include "screen-private.h"
 #include "util.h"
@@ -152,7 +153,6 @@ struct _MetaWindow
 
   /* Minimize is the state controlled by the minimize button */
   guint minimized : 1;
-  guint was_minimized : 1;
   guint tab_unminimized : 1;
 
   /* Whether the window is mapped; actual server-side state
@@ -165,6 +165,15 @@ struct _MetaWindow
    */
   guint hidden : 1;
 
+  /* Whether the compositor thinks the window is visible
+   */
+  guint visible_to_compositor : 1;
+
+  /* When we next show or hide the window, what effect we should
+   * tell the compositor to perform.
+   */
+  guint pending_compositor_effect : 4; /* MetaCompEffect */
+
   /* Iconic is the state in WM_STATE; happens for workspaces/shading
    * in addition to minimize
    */
@@ -358,9 +367,7 @@ struct _MetaWindow
   /* maintained by group.c */
   MetaGroup *group;
 
-#ifdef HAVE_COMPOSITE_EXTENSIONS
   GObject *compositor_private;
-#endif
 };
 
 struct _MetaWindowClass
@@ -391,9 +398,10 @@ struct _MetaWindowClass
 MetaWindow* meta_window_new                (MetaDisplay *display,
                                             Window       xwindow,
                                             gboolean     must_be_viewable);
-MetaWindow* meta_window_new_with_attrs     (MetaDisplay *display,
-                                            Window       xwindow,
-                                            gboolean     must_be_viewable,
+MetaWindow* meta_window_new_with_attrs     (MetaDisplay       *display,
+                                            Window             xwindow,
+                                            gboolean           must_be_viewable,
+                                            MetaCompEffect     effect,
                                             XWindowAttributes *attrs);
 void        meta_window_unmanage           (MetaWindow  *window,
                                             guint32      timestamp);
@@ -481,16 +489,6 @@ void        meta_window_get_geometry         (MetaWindow  *window,
                                               int         *y,
                                               int         *width,
                                               int         *height);
-void        meta_window_get_xor_rect         (MetaWindow          *window,
-                                              const MetaRectangle *grab_wireframe_rect,
-                                              MetaRectangle       *xor_rect);
-void        meta_window_begin_wireframe (MetaWindow *window);
-void        meta_window_update_wireframe (MetaWindow *window,
-                                          int         x,
-                                          int         y,
-                                          int         width,
-                                          int         height);
-void        meta_window_end_wireframe (MetaWindow *window);
 
 void        meta_window_kill               (MetaWindow  *window);
 void        meta_window_focus              (MetaWindow  *window,
@@ -574,8 +572,6 @@ void meta_window_free_delete_dialog (MetaWindow *window);
 void     meta_window_foreach_transient        (MetaWindow            *window,
                                                MetaWindowForeachFunc  func,
                                                void                  *data);
-gboolean meta_window_is_ancestor_of_transient (MetaWindow            *window,
-                                               MetaWindow            *transient);
 void     meta_window_foreach_ancestor         (MetaWindow            *window,
                                                MetaWindowForeachFunc  func,
                                                void                  *data);
